// Copyright (C) 2010 - DIGITEO - Michael Baudin
// Copyright (C) 1993 - 1995 - Anders Holtsberg
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function []=plotsym(x,y,a3,a4,a5,a6,a7)
  [nargout,nargin] = argn(0)
  //PLOTS    Plot with symbols
  // 
  //	  plotsym(x,y,S)
  //	  plotsym(x,y,s,S,c,C,symsize)
  // 
  //	  Input S is one of the following
  // 
  //	  's'  square
  //         'd'  diamond
  //         't'  triangle
  //	  'i'  inverted triangle
  //	  'l'  left triangle
  //	  'r'  right triangle
  //	  'c'  circle
  //	
  //	  In the longer call s is vector that contains category marker that
  //	  is plotted with symbol from text string S, i.e element i is
  //	  plotted with symbol S(s(i)), c is vector for colormarking, and
  //	  C is corresponding string of 'rgbcymwk' in permuted order. If C
  //	  is omitted then c is taken as a colour in itself. The colors
  //	  may then be changed by calling colormap. The input symsize
  //	  defines the symbol size relative to the default size which is 1.
  //	  It may be a scalar, which is then applied to all symbols, or a
  //	  vector, one for each symbol. Examples:
  // 
  //	  plotsym(x,y,z,'st','rb')
  //	     Points x,y are plotted with red squares (z=1) or blue
  //	     triangles (z=2).
  // 
  //	  plotsym(x,y,'s',z,2)
  //	     Points x,y are plotted with squares of twice the standard
  //	     size, filled with colors according to value in z and current
  //	     colormap.
  // 
  //	  See also PLOT and COLORMAP
  
  x = x(:);
  y = y(:);
  n =size(x,'*');
  
  symbol = ones(n,1);
  symboltable = 'stcidlr';
  clr = [];
  colortable = [];
  symsize = ones(n,1);
  
  s1 = 1;
  s2 = 1;
  for i = 3:nargin
    v = evstr(['a'+string(i)]);
    if type(v)==10 then
      if s1==1 then
	symboltable = v;
	s1 = 2;
	s2 = 2;
      else
	colortable = v;
	s2 = 3;
      end
    else
      if s2==1 then
	symbol = v;
	s2 = 2;
      elseif s2==2 then
	clr = v;
	s2 = 3;
      else
	symsize = v;
      end
    end
  end

  if clr==[] then
    if colortable==[] then colortable = 'rbgcmywk'; end
    if length(colortable)<max(symbol) then 
      colortable=colortable+part(colortable,ones(1,max(symbol)- ...
						 length(colortable)))
    end
    clr = part(colortable,symbol);
  elseif colortable~=[] then
    clr = part(colortable,clr);
  elseif size(clr,'*')<size(x,'*') then
    clr = clr(symbol);
  end
  if type(clr)==10 then
    c=clr;    clr=[]
    for i=1:length(c)
      select part(c,i)
       case 'r' then
	clr=[clr;color('red')]
       case 'b' then
	clr=[clr;color('blue')]
       case 'g' then
	clr=[clr;color('green')]
       case 'c' then
	clr=[clr;color('cyan')]
       case 'b' then
	clr=[clr;color('blue')]
       case 'm' then
	clr=[clr;color('maroon')]
       case 'y' then
	clr=[clr;color('yellow')]
       case 'w' then
	clr=[clr;color('white')]
       case 'k' then
	clr=[clr;color('black')]
      end
    end
  end

 
  symbol = part(symboltable,symbol);
  if size(symsize,'*')==1 then
    symsize = symsize(ones(n,1));
  end
  drawlater()
  ishold=%F;
  //A VOIR
  if ~ishold then
    clf();
    xx0=floor(min(x));xx1=ceil(max(x));
    yy0=floor(min(y));yy1=ceil(max(y));  
    ax=gca();ax.axes_visible='on';
    ax.data_bounds=[xx0,yy0;xx1,yy1];
    sx = max(x)-min(x);
    sy = max(y)-min(y);
  else
    ax=gca()
    a = ax.data_bounds;
    sx = max([a(2);x])-min([a(1);x]);
    sy = max([a(4);y])-min([a(3);y]);
  end
  //P = get(gca(),'Position');
  P=[0.12 0.12 0.76 0.76];
  P = P(3)/P(4);
  dx = sx/25/P/1.3;
  dy = sy/25;
  
  Ss = [-1,1,1,-1;-1,-1,1,1]/4;
  Ds = [-1,0,1,0;0,-1,0,1]/2/sqrt(2);
  Ts = [-sqrt(3)/2,0,sqrt(3)/2;0.5,-1,0.5]/sqrt(3)/1.5;
  Is = [-sqrt(3)/2,0,sqrt(3)/2;-0.5,1,-0.5]/sqrt(3)/1.5;
  Ls = [0.5,-1,0.5;-sqrt(3)/2,0,sqrt(3)/2]/sqrt(3)/1.5;
  Rs = [-0.5,1,-0.5;-sqrt(3)/2,0,sqrt(3)/2]/sqrt(3)/1.5;
  Cs = [sin(%pi*(0:31)/16);cos(%pi*(0:31)/16)]/%pi;

  for i = 1:n
    si = part(symbol,i);
    if si=='s' then
      sym = Ss;
    elseif si=='d' then
      sym = Ds;
    elseif si=='t' then
      sym = Ts;
    elseif si=='i' then
      sym = Is;
    elseif si=='l' then
      sym = Ls;
    elseif si=='r' then
      sym = Rs;
    elseif si=='c' then
      sym = Cs;
    end
    XX=x(i)+dx*symsize(i)*sym(1,:);
    YY=y(i)+dy*symsize(i)*sym(2,:);

    if prod(size(clr)) <> 1,
      xfpolys(XX',YY',clr(i));
    else
      xfpolys(XX',YY',clr);
    end
  end
  ax.box='on';
  drawnow()
  

endfunction
