// Copyright (C) 2010 - DIGITEO - Michael Baudin
// Copyright (C) 1993 - 1995 - Anders Holtsberg
// Copyright (C) 1998 - 2000 - Mathematique Universite de Paris-Sud - Jean Coursol
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function [x]=rpoiss(n,l)
x=[];
[nargout,nargin] = argn(0)
//RJPOISSON   Random numbers from the poisson distribution (renewal method)
// 
//         x=rpoiss(n,l)
//       Input    n  positive integer or vector [lig,col] of integers
//                l  positive real
// 
//       Output   x  vector or matrix of random numbers
//                   chosen from a poisson distribution with parameter l
// 
 

if nargin~=2 then
  error('Wrong number of input parameters');
  return
   
end
 
if mtlb_length(n)==1 then
  n = [n,1];
end
 
if mtlb_length(n)>2|mtlb_length(l)>1 then
  error('Wrong input parameter type');
  return
   
end
 
if l<=0 then
  error('Wrong input parameter value');
  return
   
end
 
s = mtlb_zeros(n);
x = s;
t = mtlb_ones(n);
while mtlb_any(t) then
  s = s+t .* rexpweib(n,1);
  x = x+t;
  t = s<l;
end
x = x-mtlb_ones(n);
endfunction
