// Copyright (C) 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//
// Check with default mu, sigma
//
computed = dnorm ( [-1 1] );
expected = [ 0.241970724519143   0.241970724519143 ];
assert_close ( computed , expected , 10 * %eps );
//
// Check expansion of mu and expansion of sigma
computed = dnorm ( [1 2 3] , 1.0 , 2.0 );
expected = [ 0.199471140200716   0.176032663382150   0.120985362259572 ];
assert_close ( computed , expected , 10 * %eps );
//
// Check with expanded arguments
computed = dnorm ( [1 2 3] , [1 1 1], [2 2 2] );
expected = [ 0.199471140200716   0.176032663382150   0.120985362259572 ];
assert_close ( computed , expected , 10 * %eps );



///////////////////////////////////////////////////////////////
//
// Test accuracy of dnorm
//
// Numerical values computed from Mathematica

// Table of inputs
// [x shape scale P precision]
precision = 10*%eps;
table = [
  1.5 , 1.0 , 2.0 , 0.1933340584014246 , 10 * %eps 
  5.0 , 1.0 , 2.0 , 0.02699548325659403 , %eps
  10.0 , 1.0 , 2.0 , 7.991870553452737e-006 , %eps
  15.0 , 1.0 , 2.0 , 4.567360204182297e-012 , %eps
  20. , 1.0 , 2.0 , 5.038967697150005e-021 , %eps
  30. , 1.0 , 2.0 , 4.412377487297412e-047 , %eps
  50. , 1.0 , 2.0 , 9.062513967757624e-132 , %eps
  76. , 1.0 , 2.0 , 8.641168661420526e-307 , %eps
];

ntests = size(table,"r");
for i = 1 : ntests
  x = table(i,1);
  mu = table(i,2);
  sigma = table(i,3);
  expected = table(i,4);
  precision = table(i,5);
  computed = dnorm ( x , mu , sigma );
  assert_close ( computed , expected , precision );
end

