// Copyright (C) 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//
function flag = assert_equal ( computed , expected )
  if ( and ( computed==expected ) ) then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

[x,txt] = getdata(10);
assert_equal ( size(x) , [38,8] );
assert_equal ( size(txt) , [48,1] );
assert_equal ( typeof(x) , "constant" );
assert_equal ( typeof(txt) , "string" );
//
for i = 1 : 23
  [x,txt] = getdata(i);
  assert_equal ( typeof(x) , "constant" );
  assert_equal ( typeof(txt) , "string" );
end
//
// A short abstract of all datasets
for i = 1 : 23
[x,txt] = getdata(i);
txt_title=txt(1);
mprintf("Dataset #%3d: %-30s (%3d-by-%-3d)\n",i,txt_title,size(x,"r"),size(x,"c"));
end

// A longer abstract of all datasets
for i = 1 : 23
[x,txt] = getdata(i);
txt_title=txt(1);
txt_source=txt(2);
txt_from=txt(3);
txt_dims=txt(4);
txt_descr=txt(5:$);
abstract = strcat(txt_descr(:)," ");
abstract = part(abstract,1:80)+"...";
mprintf("\nDataset #%3d: %-30s (%3d-by-%-3d)\n",i,txt_title,size(x,"r"),size(x,"c"));
mprintf("\t%s\n",txt_source);
mprintf("\t%s\n",txt_from);
mprintf("\t%s\n",txt_dims);
mprintf("\t%s\n",abstract);
end

