// Copyright (C) 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

x = rchisq(1000,3);
scf();
[h,edge]=histo(x);
assert_equal ( typeof(h) , "constant" );
assert_equal ( and(h>=0) , %t );
assert_equal ( typeof(edge) , "constant" );
//
// Sets the approximate number of classes
clf(); 
[h,edge]=histo(x,10);
assert_equal ( typeof(h) , "constant" );
assert_equal ( and(h>=0) , %t );
assert_equal ( typeof(edge) , "constant" );
  //
// See how the edges moves when we configure the odd argument
clf(); histo(x,[],1);
clf(); histo(x,[],10);
clf(); histo(x,[],100);
  //
// See without scaling
clf(); histo(x,[],[],0);
// See with scaling
clf(); histo(x,[],[],1);
  //
// See various colors and styles
clf(); histo(x,[],[],[],1);
clf(); histo(x,[],[],[],2);
clf(); histo(x,[],[],[],3);

